State

Struct State 

pub struct State { /* private fields */ }
The persistent state database.

Implementations

Source

impl State

pub fn open(path: &Path) -> VtaResult<State>

Open (creating if absent) the state database at path and ensure the schema-version marker is present.

pub fn schema_version(&self) -> VtaResult<u32>

The on-disk schema version (0 if unset).

pub fn put_store_entry( &self, store_key: &str, meta: &StoreEntryMeta, ) -> VtaResult<()>

Record (or replace) the metadata for a store entry, keyed by its store key.

pub fn get_store_entry( &self, store_key: &str, ) -> VtaResult<Option<StoreEntryMeta>>

Look up store-entry metadata by store key.

pub fn append_generation(&self, rec: &GenerationRecord) -> VtaResult<()>

Append a generation record (keyed by its id).

pub fn get_generation(&self, id: u64) -> VtaResult<Option<GenerationRecord>>

Fetch a generation record by id.

pub fn set_current(&self, id: u64) -> VtaResult<()>

Set the current (active) generation pointer.

pub fn current(&self) -> VtaResult<Option<u64>>

The current (active) generation id, if any.

pub fn put_resolution(&self, config_hash: &str, bytes: &[u8]) -> VtaResult<()>

Store a raw resolution-cache entry (opaque bytes keyed by a config hash).

pub fn get_resolution(&self, config_hash: &str) -> VtaResult<Option<Vec<u8>>>

Fetch a raw resolution-cache entry.